/* selectionbar.c generated by valac 0.34.0.71-0c51, the Vala compiler
 * generated from selectionbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;
typedef struct _BoxesSelectionbarPrivate BoxesSelectionbarPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block76Data Block76Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block77Data Block77Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

struct _BoxesSelectionbar {
	GtkRevealer parent_instance;
	BoxesSelectionbarPrivate * priv;
};

struct _BoxesSelectionbarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesSelectionbarPrivate {
	GtkToggleButton* favorite_btn;
	GtkButton* pause_btn;
	GtkButton* remove_btn;
	GtkButton* open_btn;
	BoxesAppWindow* window;
	gboolean ignore_favorite_btn_clicks;
};

struct _Block76Data {
	int _ref_count_;
	BoxesSelectionbar* self;
	BoxesAppWindow* window;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _Block77Data {
	int _ref_count_;
	BoxesSelectionbar* self;
	BoxesMachine* machine;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesAsyncLauncher* async_launcher;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_selectionbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_SELECTIONBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarPrivate))
enum  {
	BOXES_SELECTIONBAR_DUMMY_PROPERTY
};
void boxes_selectionbar_setup_ui (BoxesSelectionbar* self, BoxesAppWindow* window);
static Block76Data* block76_data_ref (Block76Data* _data76_);
static void block76_data_unref (void * _userdata_);
static void __lambda193_ (Block76Data* _data76_);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
static void ___lambda193__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_selectionbar_on_favorite_btn_clicked (BoxesSelectionbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GList* boxes_app_get_selected_items (BoxesApp* self);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
static void _boxes_selectionbar_on_favorite_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_on_pause_btn_clicked (BoxesSelectionbar* self);
static Block77Data* block77_data_ref (Block77Data* _data77_);
static void block77_data_unref (void * _userdata_);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void ____lambda194_ (Block77Data* _data77_, GObject* obj, GAsyncResult* _result_);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void _____lambda194__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _boxes_selectionbar_on_pause_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_on_open_btn_clicked (BoxesSelectionbar* self);
void boxes_app_open_selected_items_in_new_window (BoxesApp* self);
static void _boxes_selectionbar_on_open_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_on_remove_btn_clicked (BoxesSelectionbar* self);
void boxes_app_remove_selected_items (BoxesApp* self);
static void _boxes_selectionbar_on_remove_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
static void boxes_selectionbar_update_delete_btn (BoxesSelectionbar* self);
GType boxes_collection_get_type (void) G_GNUC_CONST;
static void ____lambda195_ (BoxesSelectionbar* self);
static void _____lambda195__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gboolean boxes_machine_get_can_delete (BoxesMachine* self);
static void boxes_selectionbar_update_open_btn (BoxesSelectionbar* self);
static void ____lambda196_ (BoxesSelectionbar* self);
static void _____lambda196__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
BoxesSelectionbar* boxes_selectionbar_new (void);
BoxesSelectionbar* boxes_selectionbar_construct (GType object_type);
static GObject * boxes_selectionbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_selectionbar___lambda197_ (BoxesSelectionbar* self);
static void __boxes_selectionbar___lambda197__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_selectionbar_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 346 "selectionbar.c"
}


static Block76Data* block76_data_ref (Block76Data* _data76_) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_atomic_int_inc (&_data76_->_ref_count_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return _data76_;
#line 355 "selectionbar.c"
}


static void block76_data_unref (void * _userdata_) {
	Block76Data* _data76_;
	_data76_ = (Block76Data*) _userdata_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (g_atomic_int_dec_and_test (&_data76_->_ref_count_)) {
#line 364 "selectionbar.c"
		BoxesSelectionbar* self;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		self = _data76_->self;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_data76_->window);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (self);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_slice_free (Block76Data, _data76_);
#line 374 "selectionbar.c"
	}
}


static void __lambda193_ (Block76Data* _data76_) {
	BoxesSelectionbar* self;
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = _data76_->self;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = _data76_->window;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_window_get_selection_mode (_tmp0_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_revealer_set_reveal_child ((GtkRevealer*) self, _tmp2_);
#line 394 "selectionbar.c"
}


static void ___lambda193__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda193_ (self);
#line 401 "selectionbar.c"
}


void boxes_selectionbar_setup_ui (BoxesSelectionbar* self, BoxesAppWindow* window) {
	Block76Data* _data76_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (window != NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_data76_ = g_slice_new0 (Block76Data);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_data76_->_ref_count_ = 1;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_data76_->self = g_object_ref (self);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = window;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (_data76_->window);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_data76_->window = _tmp1_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _data76_->window;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->window);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->window = _tmp3_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = _data76_->window;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_data ((GObject*) _tmp4_, "notify::selection-mode", (GCallback) ___lambda193__g_object_notify, block76_data_ref (_data76_), (GClosureNotify) block76_data_unref, 0);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	block76_data_unref (_data76_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_data76_ = NULL;
#line 446 "selectionbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 453 "selectionbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_list_free (self);
#line 462 "selectionbar.c"
}


static void boxes_selectionbar_on_favorite_btn_clicked (BoxesSelectionbar* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	BoxesAppWindow* _tmp13_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = self->priv->ignore_favorite_btn_clicks;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (_tmp0_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		return;
#line 480 "selectionbar.c"
	}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_app;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = boxes_app_get_selected_items (_tmp1_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 488 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp3_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 496 "selectionbar.c"
			BoxesCollectionItem* _tmp4_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp4_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp4_;
#line 503 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
				BoxesMachine* _tmp8_ = NULL;
				BoxesBoxConfig* _tmp9_ = NULL;
				GtkToggleButton* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp6_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = machine;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp7_ == NULL) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 530 "selectionbar.c"
				}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = machine;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = _tmp8_->config;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = self->priv->favorite_btn;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = gtk_toggle_button_get_active (_tmp10_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = _tmp11_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				boxes_box_config_set_category (_tmp9_, "favorite", _tmp12_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 548 "selectionbar.c"
			}
		}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 553 "selectionbar.c"
	}
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = self->priv->window;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_window_set_selection_mode (_tmp13_, FALSE);
#line 559 "selectionbar.c"
}


static void _boxes_selectionbar_on_favorite_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_favorite_btn_clicked ((BoxesSelectionbar*) self);
#line 566 "selectionbar.c"
}


static Block77Data* block77_data_ref (Block77Data* _data77_) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_atomic_int_inc (&_data77_->_ref_count_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return _data77_;
#line 575 "selectionbar.c"
}


static void block77_data_unref (void * _userdata_) {
	Block77Data* _data77_;
	_data77_ = (Block77Data*) _userdata_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (g_atomic_int_dec_and_test (&_data77_->_ref_count_)) {
#line 584 "selectionbar.c"
		BoxesSelectionbar* self;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		self = _data77_->self;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_data77_->machine);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (self);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_slice_free (Block77Data, _data77_);
#line 594 "selectionbar.c"
	}
}


static void ____lambda194_ (Block77Data* _data77_, GObject* obj, GAsyncResult* _result_) {
	BoxesSelectionbar* self;
	GError * _inner_error_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = _data77_->self;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (_result_ != NULL);
#line 606 "selectionbar.c"
	{
		BoxesMachine* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp0_ = _data77_->machine;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp1_ = _result_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		boxes_machine_save_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 618 "selectionbar.c"
			goto __catch73_g_error;
		}
	}
	goto __finally73;
	__catch73_g_error:
	{
		GError* e = NULL;
		BoxesAppWindow* _tmp2_ = NULL;
		BoxesNotificationbar* _tmp3_ = NULL;
		BoxesNotificationbar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		BoxesMachine* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GdNotification* _tmp11_ = NULL;
		GdNotification* _tmp12_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		e = _inner_error_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_inner_error_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp2_ = self->priv->window;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = boxes_app_window_get_notificationbar (_tmp2_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = _tmp3_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = _ ("Pausing “%s” failed");
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp6_ = _data77_->machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp7_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp6_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp8_ = _tmp7_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp9_ = g_strdup_printf (_tmp5_, _tmp8_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp10_ = _tmp9_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp11_ = boxes_notificationbar_display_error (_tmp4_, _tmp10_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp12_ = _tmp11_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_tmp12_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_free0 (_tmp10_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_error_free0 (e);
#line 669 "selectionbar.c"
	}
	__finally73:
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		return;
#line 680 "selectionbar.c"
	}
}


static void _____lambda194__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	____lambda194_ (self, source_object, res);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	block77_data_unref (self);
#line 690 "selectionbar.c"
}


static void boxes_selectionbar_on_pause_btn_clicked (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GtkButton* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 708 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 716 "selectionbar.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 723 "selectionbar.c"
			{
				Block77Data* _data77_;
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesMachine* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data77_ = g_slice_new0 (Block77Data);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data77_->_ref_count_ = 1;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data77_->self = g_object_ref (self);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data77_->machine = _tmp5_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _data77_->machine;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp6_ == NULL) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					block77_data_unref (_data77_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_data77_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 754 "selectionbar.c"
				}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = _data77_->machine;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				boxes_machine_save (_tmp7_, _____lambda194__gasync_ready_callback, block77_data_ref (_data77_));
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				block77_data_unref (_data77_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data77_ = NULL;
#line 766 "selectionbar.c"
			}
		}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 771 "selectionbar.c"
	}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = self->priv->pause_btn;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, FALSE);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = self->priv->window;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_window_set_selection_mode (_tmp9_, FALSE);
#line 781 "selectionbar.c"
}


static void _boxes_selectionbar_on_pause_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_pause_btn_clicked ((BoxesSelectionbar*) self);
#line 788 "selectionbar.c"
}


static void boxes_selectionbar_on_open_btn_clicked (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_open_selected_items_in_new_window (_tmp0_);
#line 800 "selectionbar.c"
}


static void _boxes_selectionbar_on_open_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_open_btn_clicked ((BoxesSelectionbar*) self);
#line 807 "selectionbar.c"
}


static void boxes_selectionbar_on_remove_btn_clicked (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_remove_selected_items (_tmp0_);
#line 819 "selectionbar.c"
}


static void _boxes_selectionbar_on_remove_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_remove_btn_clicked ((BoxesSelectionbar*) self);
#line 826 "selectionbar.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	for (i = 0; i < stack_length; i++) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			return TRUE;
#line 838 "selectionbar.c"
		}
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return FALSE;
#line 843 "selectionbar.c"
}


static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self) {
	gboolean active = FALSE;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	gboolean _tmp5_ = FALSE;
	BoxesApp* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
	GList* _tmp8_ = NULL;
	GtkToggleButton* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	GtkToggleButton* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	active = FALSE;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_ > ((guint) 0);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp5_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = boxes_app_app;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = boxes_app_get_selected_items (_tmp6_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = _tmp7_;
#line 889 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp8_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 897 "selectionbar.c"
			BoxesCollectionItem* _tmp9_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp9_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp9_;
#line 904 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp10_ = NULL;
				BoxesMachine* _tmp11_ = NULL;
				BoxesMachine* _tmp12_ = NULL;
				gboolean is_favorite = FALSE;
				BoxesMachine* _tmp13_ = NULL;
				BoxesBoxConfig* _tmp14_ = NULL;
				gchar** _tmp15_ = NULL;
				gint _tmp15__length1 = 0;
				gchar** _tmp16_ = NULL;
				gint _tmp16__length1 = 0;
				gchar** _tmp17_ = NULL;
				gint _tmp17__length1 = 0;
				gboolean _tmp18_ = FALSE;
				gboolean _tmp19_ = FALSE;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = item;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp11_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = machine;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp12_ == NULL) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 937 "selectionbar.c"
				}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp13_ = machine;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = _tmp13_->config;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp15_ = boxes_box_config_get_categories (_tmp14_, &_tmp15__length1);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp16_ = _tmp15_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp16__length1 = _tmp15__length1;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = _tmp16_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17__length1 = _tmp16__length1;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp18_ = _vala_string_array_contains (_tmp17_, _tmp16__length1, "favorite");
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = (_vala_array_free (_tmp17_, _tmp17__length1, (GDestroyNotify) g_free), NULL);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				is_favorite = _tmp18_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp19_ = active;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (!_tmp19_) {
#line 963 "selectionbar.c"
					gboolean _tmp20_ = FALSE;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp20_ = is_favorite;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					active = _tmp20_;
#line 969 "selectionbar.c"
				} else {
					gboolean _tmp21_ = FALSE;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp21_ = is_favorite;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					if (!_tmp21_) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						sensitive = FALSE;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (machine);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (item);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						break;
#line 984 "selectionbar.c"
					}
				}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 991 "selectionbar.c"
			}
		}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 996 "selectionbar.c"
	}
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->ignore_favorite_btn_clicks = TRUE;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->favorite_btn;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = active;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toggle_button_set_active (_tmp22_, _tmp23_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = self->priv->favorite_btn;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp25_ = sensitive;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp24_, _tmp25_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->ignore_favorite_btn_clicks = FALSE;
#line 1014 "selectionbar.c"
}


static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self) {
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GtkButton* _tmp10_ = NULL;
	gboolean _tmp11_ = FALSE;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = FALSE;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 1035 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1043 "selectionbar.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 1050 "selectionbar.c"
			{
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
				gboolean _tmp8_ = FALSE;
				gboolean _tmp9_ = FALSE;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE)) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 1067 "selectionbar.c"
				}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp6_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = machine;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = boxes_machine_get_can_save (_tmp7_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = _tmp8_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp9_) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					sensitive = TRUE;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					break;
#line 1091 "selectionbar.c"
				}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1097 "selectionbar.c"
			}
		}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1102 "selectionbar.c"
	}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp10_ = self->priv->pause_btn;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = sensitive;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, _tmp11_);
#line 1110 "selectionbar.c"
}


static void ____lambda195_ (BoxesSelectionbar* self) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_delete_btn (self);
#line 1117 "selectionbar.c"
}


static void _____lambda195__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	____lambda195_ ((BoxesSelectionbar*) self);
#line 1124 "selectionbar.c"
}


static void boxes_selectionbar_update_delete_btn (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
	gpointer* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp11_ = NULL;
	GList* _tmp12_ = NULL;
	GList* _tmp13_ = NULL;
	GList* _tmp14_ = NULL;
	guint _tmp15_ = 0U;
	gboolean _tmp16_ = FALSE;
	BoxesApp* _tmp17_ = NULL;
	GList* _tmp18_ = NULL;
	GList* _tmp19_ = NULL;
	GtkButton* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _tmp0_->collection;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_->items;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_->pdata;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3__length1 = (gint) _tmp2_->len;
#line 1158 "selectionbar.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp3_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection_length1 = _tmp3__length1;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = 0; item_it < _tmp3__length1; item_it = item_it + 1) {
#line 1170 "selectionbar.c"
			BoxesCollectionItem* _tmp4_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp4_ = _g_object_ref0 (item_collection[item_it]);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp4_;
#line 1177 "selectionbar.c"
			{
				gulong can_delete_id = 0UL;
				BoxesCollectionItem* _tmp5_ = NULL;
				gconstpointer _tmp6_ = NULL;
				gulong _tmp7_ = 0UL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = g_object_get_data ((GObject*) _tmp5_, "can_delete_id");
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				can_delete_id = (gulong) ((guintptr) _tmp6_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = can_delete_id;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp7_ > ((gulong) 0)) {
#line 1193 "selectionbar.c"
					BoxesCollectionItem* _tmp8_ = NULL;
					gulong _tmp9_ = 0UL;
					BoxesCollectionItem* _tmp10_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp8_ = item;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp9_ = can_delete_id;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp10_ = item;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					g_object_set_data_full ((GObject*) _tmp10_, "can_delete_id", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1207 "selectionbar.c"
				}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1211 "selectionbar.c"
			}
		}
	}
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = boxes_app_app;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp12_ = boxes_app_get_selected_items (_tmp11_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = _tmp12_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp14_ = _tmp13_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = g_list_length (_tmp14_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = _tmp15_ > ((guint) 0);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp14_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp16_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp17_ = boxes_app_app;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp18_ = boxes_app_get_selected_items (_tmp17_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp19_ = _tmp18_;
#line 1237 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp19_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1245 "selectionbar.c"
			BoxesCollectionItem* _tmp20_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp20_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp20_;
#line 1252 "selectionbar.c"
			{
				gulong can_delete_id = 0UL;
				BoxesCollectionItem* _tmp21_ = NULL;
				gulong _tmp22_ = 0UL;
				BoxesCollectionItem* _tmp23_ = NULL;
				gulong _tmp24_ = 0UL;
				gboolean _tmp25_ = FALSE;
				BoxesCollectionItem* _tmp26_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				can_delete_id = (gulong) 0;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp21_ = item;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp22_ = g_signal_connect_object ((GObject*) _tmp21_, "notify::can-delete", (GCallback) _____lambda195__g_object_notify, self, 0);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				can_delete_id = _tmp22_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp23_ = item;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp24_ = can_delete_id;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				g_object_set_data_full ((GObject*) _tmp23_, "can_delete_id", (gpointer) ((guintptr) _tmp24_), NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp26_ = item;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, BOXES_TYPE_MACHINE)) {
#line 1279 "selectionbar.c"
					BoxesCollectionItem* _tmp27_ = NULL;
					gboolean _tmp28_ = FALSE;
					gboolean _tmp29_ = FALSE;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp27_ = item;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp28_ = boxes_machine_get_can_delete (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp27_) : NULL);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp29_ = _tmp28_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp25_ = !_tmp29_;
#line 1291 "selectionbar.c"
				} else {
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp25_ = FALSE;
#line 1295 "selectionbar.c"
				}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp25_) {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					sensitive = FALSE;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					break;
#line 1305 "selectionbar.c"
				}
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1309 "selectionbar.c"
			}
		}
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1314 "selectionbar.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp30_ = self->priv->remove_btn;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp31_ = sensitive;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp30_, _tmp31_);
#line 1322 "selectionbar.c"
}


static void ____lambda196_ (BoxesSelectionbar* self) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_open_btn (self);
#line 1329 "selectionbar.c"
}


static void _____lambda196__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	____lambda196_ ((BoxesSelectionbar*) self);
#line 1336 "selectionbar.c"
}


static void boxes_selectionbar_update_open_btn (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
	gpointer* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint items = 0U;
	BoxesApp* _tmp11_ = NULL;
	GList* _tmp12_ = NULL;
	GList* _tmp13_ = NULL;
	GList* _tmp14_ = NULL;
	guint _tmp15_ = 0U;
	guint _tmp16_ = 0U;
	gboolean sensitive = FALSE;
	guint _tmp17_ = 0U;
	BoxesApp* _tmp18_ = NULL;
	GList* _tmp19_ = NULL;
	GList* _tmp20_ = NULL;
	GtkButton* _tmp31_ = NULL;
	gboolean _tmp32_ = FALSE;
	guint _tmp33_ = 0U;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _tmp0_->collection;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_->items;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_->pdata;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3__length1 = (gint) _tmp2_->len;
#line 1373 "selectionbar.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp3_;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection_length1 = _tmp3__length1;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = 0; item_it < _tmp3__length1; item_it = item_it + 1) {
#line 1385 "selectionbar.c"
			BoxesCollectionItem* _tmp4_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp4_ = _g_object_ref0 (item_collection[item_it]);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp4_;
#line 1392 "selectionbar.c"
			{
				gulong importing_id = 0UL;
				BoxesCollectionItem* _tmp5_ = NULL;
				gconstpointer _tmp6_ = NULL;
				gulong _tmp7_ = 0UL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = g_object_get_data ((GObject*) _tmp5_, "importing_id");
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				importing_id = (gulong) ((guintptr) _tmp6_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = importing_id;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp7_ > ((gulong) 0)) {
#line 1408 "selectionbar.c"
					BoxesCollectionItem* _tmp8_ = NULL;
					gulong _tmp9_ = 0UL;
					BoxesCollectionItem* _tmp10_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp8_ = item;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp9_ = importing_id;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp10_ = item;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					g_object_set_data_full ((GObject*) _tmp10_, "importing_id", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1422 "selectionbar.c"
				}
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1426 "selectionbar.c"
			}
		}
	}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = boxes_app_app;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp12_ = boxes_app_get_selected_items (_tmp11_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = _tmp12_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp14_ = _tmp13_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = g_list_length (_tmp14_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = _tmp15_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp14_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	items = _tmp16_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp17_ = items;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp17_ > ((guint) 0);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp18_ = boxes_app_app;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp19_ = boxes_app_get_selected_items (_tmp18_);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp20_ = _tmp19_;
#line 1456 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp20_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1464 "selectionbar.c"
			BoxesCollectionItem* _tmp21_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp21_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp21_;
#line 1471 "selectionbar.c"
			{
				gulong importing_id = 0UL;
				BoxesCollectionItem* _tmp22_ = NULL;
				gulong _tmp23_ = 0UL;
				BoxesCollectionItem* _tmp24_ = NULL;
				gulong _tmp25_ = 0UL;
				gboolean _tmp26_ = FALSE;
				BoxesCollectionItem* _tmp27_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				importing_id = (gulong) 0;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp22_ = item;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp23_ = g_signal_connect_object ((GObject*) _tmp22_, "notify::importing", (GCallback) _____lambda196__g_object_notify, self, 0);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				importing_id = _tmp23_;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp24_ = item;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp25_ = importing_id;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				g_object_set_data_full ((GObject*) _tmp24_, "importing_id", (gpointer) ((guintptr) _tmp25_), NULL);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp27_ = item;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 1498 "selectionbar.c"
					BoxesCollectionItem* _tmp28_ = NULL;
					gboolean _tmp29_ = FALSE;
					gboolean _tmp30_ = FALSE;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp28_ = item;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp29_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp28_) : NULL);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp30_ = _tmp29_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp26_ = _tmp30_;
#line 1510 "selectionbar.c"
				} else {
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp26_ = FALSE;
#line 1514 "selectionbar.c"
				}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp26_) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					sensitive = FALSE;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					break;
#line 1524 "selectionbar.c"
				}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1528 "selectionbar.c"
			}
		}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1533 "selectionbar.c"
	}
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp31_ = self->priv->open_btn;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp32_ = sensitive;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp31_, _tmp32_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp33_ = items;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (_tmp33_ == ((guint) 0)) {
#line 1545 "selectionbar.c"
		GtkButton* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp34_ = self->priv->open_btn;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp35_ = C_ ("0 items selected", "_Open in new window");
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		gtk_button_set_label (_tmp34_, _tmp35_);
#line 1554 "selectionbar.c"
	} else {
		GtkButton* _tmp36_ = NULL;
		guint _tmp37_ = 0U;
		const gchar* _tmp38_ = NULL;
		guint _tmp39_ = 0U;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp36_ = self->priv->open_btn;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp37_ = items;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp38_ = ngettext ("_Open in new window", "_Open in %u new windows", (gulong) _tmp37_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp39_ = items;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp40_ = g_strdup_printf (_tmp38_, _tmp39_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp41_ = _tmp40_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		gtk_button_set_label (_tmp36_, _tmp41_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_free0 (_tmp41_);
#line 1578 "selectionbar.c"
	}
}


BoxesSelectionbar* boxes_selectionbar_construct (GType object_type) {
	BoxesSelectionbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = (BoxesSelectionbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return self;
#line 1589 "selectionbar.c"
}


BoxesSelectionbar* boxes_selectionbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return boxes_selectionbar_construct (BOXES_TYPE_SELECTIONBAR);
#line 1596 "selectionbar.c"
}


static void _boxes_selectionbar___lambda197_ (BoxesSelectionbar* self) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_favorite_btn (self);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_pause_btn (self);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_delete_btn (self);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_open_btn (self);
#line 1609 "selectionbar.c"
}


static void __boxes_selectionbar___lambda197__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_boxes_selectionbar___lambda197_ ((BoxesSelectionbar*) self);
#line 1616 "selectionbar.c"
}


static GObject * boxes_selectionbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSelectionbar * self;
	BoxesApp* _tmp0_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_selectionbar_parent_class);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::selected-items", (GCallback) __boxes_selectionbar___lambda197__g_object_notify, self, 0);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return obj;
#line 1637 "selectionbar.c"
}


static void boxes_selectionbar_class_init (BoxesSelectionbarClass * klass) {
	gint BoxesSelectionbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSelectionbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_selectionbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_selectionbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	BoxesSelectionbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/selectionbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "favorite_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, favorite_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "pause_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, pause_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "remove_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, remove_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "open_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, open_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_favorite_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_favorite_btn_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_pause_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_pause_btn_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_open_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_open_btn_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_remove_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_remove_btn_clicked_gtk_button_clicked));
#line 1671 "selectionbar.c"
}


static void boxes_selectionbar_instance_init (BoxesSelectionbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv = BOXES_SELECTIONBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1680 "selectionbar.c"
}


static void boxes_selectionbar_finalize (GObject* obj) {
	BoxesSelectionbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->favorite_btn);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->pause_btn);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->remove_btn);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->open_btn);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->window);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (boxes_selectionbar_parent_class)->finalize (obj);
#line 1700 "selectionbar.c"
}


GType boxes_selectionbar_get_type (void) {
	static volatile gsize boxes_selectionbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selectionbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSelectionbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_selectionbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSelectionbar), 0, (GInstanceInitFunc) boxes_selectionbar_instance_init, NULL };
		GType boxes_selectionbar_type_id;
		boxes_selectionbar_type_id = g_type_register_static (gtk_revealer_get_type (), "BoxesSelectionbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_selectionbar_type_id__volatile, boxes_selectionbar_type_id);
	}
	return boxes_selectionbar_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1719 "selectionbar.c"
		int i;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1727 "selectionbar.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1739 "selectionbar.c"
}



